pub(crate) fn argument<S>(
name: impl Into<Box<str>>,
argument_type: ArgumentType,
) -> CommandNodeBuilder<S>Expand description
Creates an argument using the standard synchronous Brigadier runtime.
pub(crate) fn argument<S>(
name: impl Into<Box<str>>,
argument_type: ArgumentType,
) -> CommandNodeBuilder<S>Creates an argument using the standard synchronous Brigadier runtime.