pub(crate) fn literal<S>(name: impl Into<Box<str>>) -> CommandNodeBuilder<S>Expand description
Creates a literal using the standard synchronous Brigadier runtime.
pub(crate) fn literal<S>(name: impl Into<Box<str>>) -> CommandNodeBuilder<S>Creates a literal using the standard synchronous Brigadier runtime.