pub(crate) struct CommandRequirementRoute<S> {
traversal: CommandRequirement<S>,
execution: CommandRequirement<S>,
}Expand description
Requirements for traversing a scoped route and executing its current node.
Fields
traversal: CommandRequirement<S>execution: CommandRequirement<S>Implementations
Sourceimpl<S> CommandRequirementRoute<S>
impl<S> CommandRequirementRoute<S>
Sourcepub(crate) const fn new(
traversal: CommandRequirement<S>,
execution: CommandRequirement<S>,
) -> Self
pub(crate) const fn new( traversal: CommandRequirement<S>, execution: CommandRequirement<S>, ) -> Self
Creates the requirements for one resolved route through a command tree.